#include <ansi_c.h>
#include <formatio.h>
#include <NIDAQmx.h>
#include <cvirte.h>		
#include <userint.h>
#include "daqtest.h"
static char tasks[128];
static int panelsel;
static float64 sample;
static TaskHandle taskHandle;


char task[6][128];

static int paneldaq;

int main (int argc, char *argv[])
   {
   if (InitCVIRTE (0, argv, 0) == 0)
      return -1;	/* out of memory */
	
   if ((paneldaq = LoadPanel (0, "daqtest.uir", PANELDAQ)) < 0) //ucitavanje panela PANELDAQ u memoriju
      return -1;
	
	
	
   DisplayPanel (paneldaq);//prikaz panela iz memorije na ekranu
	
	
	
   DAQmxLoadTask ("napon0", &taskHandle); //ucitavanje taska "napon0"
	
	
   RunUserInterface (); //ulazak u glavnu petlju
	

   DAQmxClearTask (taskHandle);//iskljucivanje taska
	
	
   DiscardPanel (paneldaq);//brisanje panela sa ekrana i iz memorije
	
	
   return 0;
   }

int CVICALLBACK Quit (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   switch (event)
      {
	  case EVENT_COMMIT:
		 QuitUserInterface (0);//izlazak iz glavne petlje
		 break;
	  
	  case EVENT_LEFT_DOUBLE_CLICK:
		 break;
	  }
   return 0;
   }

int CVICALLBACK Tick (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   int enable;
   unsigned char fileName[MAX_PATHNAME_LEN];
   double minimum, maximum;
   switch (event)
      {
	  case EVENT_TIMER_TICK:
		 DAQmxReadAnalogScalarF64 (taskHandle, 10.0, &sample, 0);//citanje taska u promenljivu sample
		 SetCtrlVal (paneldaq, PANELDAQ_THERM, sample);//prikaz sample na termometru
		 PlotStripChartPoint (paneldaq, PANELDAQ_STRIPCHART, sample);//prikaz sample na stripchartu
			
		 GetCtrlVal (paneldaq, PANELDAQ_MINIMUM, &minimum);//ocitavanje donjeg praga
		 	
		 if (sample < minimum) SetCtrlVal(paneldaq,PANELDAQ_ALARMLO,1);//ako je sample<donji prag pali se dioda
		 else  SetCtrlVal(paneldaq,PANELDAQ_ALARMLO,0);//ako ne gasi se
			
            
		 GetCtrlVal (paneldaq, PANELDAQ_MAXIMUM, &maximum);//ocitavanje gornjeg praga
         			
		 if (sample > maximum) SetCtrlVal(paneldaq,PANELDAQ_ALARMHI,1);//ako je sample > gornji prag pali se dioda
		 else  SetCtrlVal(paneldaq,PANELDAQ_ALARMHI,0);//ako ne gasi se
			
			
		 GetCtrlVal (paneldaq, PANELDAQ_ENABLE, &enable);//ocitavanje vrednosti kontrole za upis u fajl
		
		 if (enable) //ako je upis dozvoljen upisuje se u fajl
		    {
			GetCtrlVal (paneldaq, PANELDAQ_FILENAME, fileName);//uzima se ime fajla
			ArrayToFile (fileName, &sample, VAL_DOUBLE, 1, 1, VAL_GROUPS_TOGETHER, VAL_GROUPS_AS_COLUMNS, VAL_CONST_WIDTH, 10,
						 VAL_ASCII, VAL_APPEND);// u jednom prolau otvaranje fajla, upis, i zatvaranja
			}
			
		 break;
      }
   return 0;
   }

int CVICALLBACK Power (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   unsigned char switchState;
   unsigned char sampleRate;
	
   switch (event)
      {
	  case EVENT_COMMIT:
		 GetCtrlVal (paneldaq, PANELDAQ_POWER, &switchState);//ucitavanje vrednosti preklopnika
		 if (switchState==1)//ako je "1" pocinje akvizicija
		    {
			GetCtrlVal(paneldaq,PANELDAQ_SAMPLERATE,&sampleRate);//uzimanje vrednosti za brzinu odabiranja
			SetCtrlAttribute (paneldaq, PANELDAQ_TIMER, ATTR_INTERVAL, sampleRate*0.01);//postavljanje periode tajmera
			
			//deaktiviranje pojedinih kontrola
			SetCtrlAttribute (paneldaq, PANELDAQ_CLEAR, ATTR_DIMMED, 1);
			SetCtrlAttribute (paneldaq, PANELDAQ_SAMPLERATE, ATTR_DIMMED, 1);
			SetCtrlAttribute (paneldaq, PANELDAQ_FILENAME, ATTR_DIMMED, 1);
				
			SetCtrlAttribute (paneldaq, PANELDAQ_TIMER, ATTR_ENABLED, 1);//ukljucenje tajmera na kraju	
			}
		 else
			{
				
			SetCtrlAttribute (paneldaq, PANELDAQ_TIMER, ATTR_ENABLED, 0);//prvo iskljucenje tajmera
			
			//ponovno aktiviranje kontrola
			SetCtrlAttribute (paneldaq, PANELDAQ_CLEAR, ATTR_DIMMED, 0);
		 	SetCtrlAttribute (paneldaq, PANELDAQ_SAMPLERATE, ATTR_DIMMED, 0);
			SetCtrlAttribute (paneldaq, PANELDAQ_FILENAME, ATTR_DIMMED, 0); 
			}
		 break;
	  case EVENT_VAL_CHANGED:

		 break;
	  case EVENT_LEFT_DOUBLE_CLICK:
		 
		 break;
	  }
   return 0;
   }

int CVICALLBACK Clear (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   switch (event)
      {
	  case EVENT_COMMIT:
	     ClearStripChart (paneldaq, PANELDAQ_STRIPCHART);//brisanje stripcharta
		 break;
      
	  case EVENT_LEFT_DOUBLE_CLICK:
		 
		 break;
	  }
   return 0;
   }

int CVICALLBACK MinCheck (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   double minimum, maximum;
   switch (event)
      {
	  case EVENT_COMMIT:
		 GetCtrlVal (paneldaq, PANELDAQ_MINIMUM, &minimum);//ocitavanje kontrole minimum
		 GetCtrlVal (paneldaq, PANELDAQ_MAXIMUM, &maximum);//ocitavanje kontrole maksimum
		 if (minimum > maximum) SetCtrlVal (paneldaq, PANELDAQ_MINIMUM, maximum) ;//ako je min>max korekcija minimuma
		 break;
	  case EVENT_VAL_CHANGED:
		 break;
	  case EVENT_LEFT_DOUBLE_CLICK:
		 break;
	  }
   return 0;
   }

int CVICALLBACK MaxCheck (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   double minimum, maximum;
   switch (event)
      {
	  case EVENT_COMMIT:
		 GetCtrlVal (paneldaq, PANELDAQ_MINIMUM, &minimum);//ocitavanje kontrole minimum
		 GetCtrlVal (paneldaq, PANELDAQ_MAXIMUM, &maximum);//ocitavanje kontrole maksimum
		 if (minimum > maximum) SetCtrlVal (paneldaq, PANELDAQ_MAXIMUM, minimum);//ako je min>max korekcija maximuma
		 break;
	  case EVENT_VAL_CHANGED:
	     break;
	  case EVENT_LEFT_DOUBLE_CLICK:
		 break;
	  }
   return 0;
   }

int CVICALLBACK Back (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   switch (event)
      {
	  case EVENT_COMMIT:
		 DiscardPanel (panelsel);//brisanje drugog panela sa ekrana i iz memorije
		 break;
	  case EVENT_LEFT_DOUBLE_CLICK:
		 break;
	  }
   return 0;
   }

int CVICALLBACK Select (int panel, int control, int event,void *callbackData, int eventData1, int eventData2)
   {
   char *result;
   unsigned char tasks_count;
	
   switch (event)
      {
	  case EVENT_COMMIT:
		 DAQmxGetSystemInfoAttribute (DAQmx_Sys_Tasks, tasks, 128);//dobijanje liste taskova u obliku task1, task2, task3, ...
		 //MessagePopup("INFO",tasks);//ovo ce da ispise odziv, za debag
		 tasks_count=0;//brojac taskova na nulu
		 result = strtok (tasks, ", "); //iz liste taskova uzima se prvi
		 while (result!=NULL) //dokle god ne dodjemo do poslednjeg taska iz liste
		    {
			strcpy (task[tasks_count], result);//kopiranje imena takuceg taska dobijenog iz liste u niz sa imenima taskova
			//MessagePopup("INFO",task[tasks_count]);//za debag
			tasks_count++;//brojac taskova se inkrementira
			result = strtok (NULL,", ");//sledeci task iz liste
		 	}
		  
		 if (tasks_count)//ako ima barem jedan task
			{
			panelsel = LoadPanel (paneldaq, "daqtest.uir", PANELSEL);//ucitavanje drugog panela u memoriju
			InstallPopup (panelsel);//prikaz na ekranu i aktivacija drugog panela
			for (unsigned char i=0;i<tasks_count;i++) //popunjavanje liste taskova u panelu
		       InsertListItem (panelsel, PANELSEL_RING, i, task[i], i);
			}
		 else MessagePopup("GRESKA", "NE POSTOJI NIJEDAN TASK");
		 break;
	  case EVENT_LEFT_DOUBLE_CLICK:
		 break;
	  }
   return 0;
   }

